#
# spec file for package tree-sitter
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         somajor 0_25
Name:           tree-sitter
Version:        0.25.3
Release:        1.2
Summary:        An incremental parsing system for programming tools
License:        GPL-2.0-only AND MIT
URL:            https://tree-sitter.github.io/
Source0:        https://github.com/tree-sitter/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Source11:       baselibs.conf
Source20:       tree-sitter-target.py
Source21:       macros.in
Source22:       macros.lua
Source23:       functions.lua
Source24:       compile-macros.sh
Source25:       treesitter_grammar.attr
Source26:       treesitter_grammar.req
BuildRequires:  cargo-packaging
BuildRequires:  rust > 1.82.0
Requires:       lib%{name}%{somajor} = %{version}
Requires:       nodejs
%{?suse_build_hwcaps_libs}

%description
Tree-sitter is a parser generator tool and an incremental parsing
library. It can build a concrete syntax tree for a source file
and efficiently update the syntax tree as the source file is
edited. Tree-sitter aims to be:

 * General enough to parse any programming language
 * Fast enough to parse on every keystroke in a text editor
 * Robust enough to provide useful results even in the presence
   of syntax errors
 * Dependency-free so that the runtime library (which is written
   in pure C) can be embedded in any application

%package     -n lib%{name}%{somajor}
Summary:        Asychronous I/O support library
Obsoletes:      lib%{name}0 < %{version}

%description -n lib%{name}%{somajor}
Tree-sitter is a parser generator tool and an incremental parsing
library. It can build a concrete syntax tree for a source file
and efficiently update the syntax tree as the source file is
edited. This is the package with the dynamically linked C library.

%package        devel
Summary:        Development files for %{name}
Requires:       lib%{name}%{somajor} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1 -a1

#remove gitignore file from docs
rm %{_builddir}/%{name}-%{version}/docs/.gitignore

cp %{SOURCE21} .
cp %{SOURCE22} .
cp %{SOURCE23} .

# fix VERSION in Makefile
sed -i -e '/^VERSION/s/:= .*$/:= %{version}/' Makefile

%build
%{cargo_build}
%make_build PREFIX=%{_prefix} LIBDIR=%{_libdir} INCLUDEDIR=%{_includedir}

sh %{SOURCE24}

%install
%make_install DESTDIR=%{buildroot} PREFIX=%{_prefix} LIBDIR=%{_libdir} INCLUDEDIR=%{_includedir}
install -p -m 0755 -D %{_builddir}/%{name}-%{version}/target/release/%{name} \
    %{buildroot}%{_bindir}/%{name}

install -Dm644 macros.treesitter %{buildroot}%{_rpmmacrodir}/macros.treesitter
install -Dm755 %{SOURCE20} %{buildroot}%{_rpmconfigdir}/$(basename %{SOURCE20})

install -Dm644 %{SOURCE25} %{buildroot}%{_fileattrsdir}/$(basename %{SOURCE25})
install -Dm755 %{SOURCE26} %{buildroot}%{_rpmconfigdir}/$(basename %{SOURCE26})

#remove .a/.la files
find %{buildroot} -type f \( -name "*.la" -o -name "*.a" \) -delete -print

# stupid workaround for "integrating" the grammars into neovim
install -d %{buildroot}%{_libdir}/tree_sitter

#fix pkgconfig file
for i in lib include; do
sed -i 's|'$i'dir=${prefix}//usr/|'$i'dir=${prefix}/usr/|g' %{buildroot}%{_libdir}/pkgconfig/%{name}.pc
done

%ldconfig_scriptlets -n lib%{name}%{somajor}

%files
%license LICENSE
%doc README.md CONTRIBUTING.md
%{_bindir}/%{name}
%{_rpmconfigdir}/%{name}-target.py
%{_rpmmacrodir}/macros.treesitter
%{_rpmconfigdir}/treesitter_grammar.req
%{_fileattrsdir}/treesitter_grammar.attr

%files -n lib%{name}%{somajor}
%license LICENSE
%{_libdir}/lib%{name}.so.*
%dir %{_libdir}/tree_sitter

%files devel
%doc docs/
%{_includedir}/tree_sitter
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Sat Apr 12 2025 Michal Vyskocil <michal.vyskocil@gmail.com>
- update to 0.25.3:
  Full changelog: https://github.com/tree-sitter/tree-sitter/releases/tag/v0.25.3
  Bug Fixes
  * Fixed an infinite loop that could happen in some grammars during error
    recovery if the end of the file was reached.
  * Fixed a parser-generation error where internal character set constants were
    given external linkage, which could cause linking errors on some platforms
    if multiple Tree-sitter parsers were linked into the same application.
- update to 0.25.2:
  Full changelog: https://github.com/tree-sitter/tree-sitter/releases/tag/v0.25.2
  Bug Fixes
  * Fixed a crash that could occur when loading WASM-compiled languages that
    were generated with an earlier version of the Tree-sitter CLI.
  * Fixed incorrect tokenization when using WASM-compiled languages, if the
    language's external scanner did not assign to result_symbol
  * Fixed an infinite loop that could occur if external scanners returned
    empty extra tokens
* Mon Feb  3 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.25.1:
  * cli: Specify abi version via env var
  * bindings: Correct Zig bindings to expose a language function
  * lib: Prevent finished_tree assertion failure
  * Correct build steps for WASM files
  * rust: Correct doc comments
* Sat Feb  1 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.25.0:
  Full changelog: https://github.com/tree-sitter/tree-sitter/releases/tag/v0.25.0
  Notices:
  * web-tree-sitter was rewritten in TypeScript
  * Parsing and Querying should be cancelled using the "progress callback",
    rather than setting a timeout or a cancellation flag
  * MISSING nodes can now be queried
  * The ts_node_child_containing_descendant function was removed; use
    ts_node_child_with_descendant
  * TSInput now includes a (mandatory) new field DecodeFunction
  Breaking:
  * Properly handle UTF-16 endianness encoding
  * Bump internal abi to 15
  * Update playground with new web bindings
  * bindings: Update swift bindings
  * cli: Remove migration code for tree-sitter.json
  * generate: Use regex_syntax::Hir for expanding regexes
  * lib: Remove ts_node_child_containing_descendant
  * lib: Add the ability to specify a custom decode function
  * web: Rewrite the library in TypeScript
  * web: Use the WASM module in the bindings, and not the other way around
  * web: Rename pattern to patternIndex in QueryMatch
  * web: Deprecate Language.query in favor of new Query
- increase minimum rust version
* Fri Jan 17 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.24.7:
  * lib: Use inclusive range check for non-empty nodes in next sibling
    computation
* Tue Dec 31 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.24.6:
  * playground: backport new playground
* Fri Dec 13 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.24.5:
  * fix(lib): correct next sibling of zero width node
  * fix(lib): use clock_gettime on macOS again
  * feat: move scripts to xtasks
  * build: configure clippy lints at the workspace level
  * chore: remove unnecessary fuzz and profile helpers
  * build: tune compiler warnings
  * fix: compiler warning
  * build: treat incompatible pointer warning as error
  * fix(lib): handle compiler warnings
  * build(cmake): link wasmtime dependencies
  * fix: sync cmake with master
* Mon Nov 11 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.24.4:
  * loader: Add language_for_configuration
  * loader: Add error message when a tree-sitter.json file is invalid
  * node: Support single-file executables via bun build --compile
  * node: Update bindings when necessary
  * Return LanguageRef in Parser::language
  * bindings: Update CMakeLists.txt file
  * cli: Pass all fields to tree-sitter.json in init
  * cli: Use contains over is in warning
  * cmake: Use current source dir for EXISTS check
  * generate: Do not set the unit reduction symbol if it's in the extras array
  * init: Use current path if unspecified
  * init: Use camel name from config in missing spots
  * lib: Simplify edge cases with zero-width tokens
  * lib: Correctly fetch the node name in query errors
  * loader: Don't print warnings if the file is not found
  * loader: Improve language lookup speed
  * bindings: Rename cmake test target
  * Memory errors in wasm_store
* Thu Oct 10 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.24.3:
  * build: fix incorrect variable checks
  * fix(lib): correct unexpected side effect in get_column when the
    lexer is at EOF
  * build(deps): bump wasmtime to v25.0.2
* Sun Oct  6 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.24.2:
  * Drop legacy binding updates
  * templates: Properly replace author email
  * templates: Update npm packages
  * bindings: Improve cmake file
  * cmake: Support amalgamated build
  * cmake: Correct library scopes
  * make: Fix tree-sitter.pc generation
* Fri Oct  4 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.24.1:
  * fix(generate): move generated header files into the generate crate
- update do 0.24.0:
  * docs: add Kotlin to the playground
  * fix(generate): remove necessary files from gitignore template
  * feat(generate): bump tree-sitter dev dependency to 0.23
  * fix(cli): remove conflicting short flags in the fuzz subcommand
  * feat(bindings): bump go-tree-sitter version
  * docs(changelog): add 0.23.0 release notes
  * feat: add an API to time out query executions
  * fix(generate): disallow inline variables referencing themselves
  * fix(rust): add missing TSNode functions
  * fix(lib): correct extra node creation from non-zero root-alias cursors
  * fix(test): exit with an error if a test marked with :error has no error
  * fix(test): retain attributes when running test -u
  * feat(language): derive Clone and Copy on LanguageFn
  * fix(lib): backtrack to the last relevant iterator if no child was found
  * fix(generate): add tree-sitter to the dev-dependencies of the Cargo.toml
  * fix(binding_web): correct edit signature
  * build(lib): build using cmake
  * fix(cli): keep skipped tests unchanged in the test/corpus
  * feat!: remove C++ support for external scanners
  * chore: clippy lints
  * feat!: remove the build-wasm subcommand
  * fix(generate): do not generate large character sets for unused variables
  * fix(binding_web): remove nonexistent function definition
  * feat: add field_name_for_named_child
  * fix(cli): remove duplicate short options from fuzz command
  * fix: correct comment quote
  * fix(generate): remove excludes in Package.swift
  * chore(bindings): update rust lib docs
  * build(deps): bump the cargo group across 1 directory with 11 updates
  * fix(docs): fix highlight readme example using compatible versions
  * fix(lib): peek at the next sibling when iterating to find the child
  * build(make): support darwin cross-compile
  * fix(wasm): use / paths for workdir
  * fix: properly handle utf8 code points for highlight and tag assertions
  * feat: add root field in node-types.json
  * fix(fuzz): skip tests marked with :skip & don't report errors on them
  * feat: add eslint configuration package
  * chore: remove compile_flags.txt
  * style(tests): do not use .as_bytes().len() on strings
  * feat: provide a rebuild flag to force rebuild parsers
  * feat(test): test all queries
  * fix(test): correctly handle assertions on empty lines
  * feat: add shell completions
  * refactor(cli): break out subcommand logic into separate functions
  * fix: do not generate spurious files if the grammar path is not the detected
  * fix: disallow empty string literals in rules
  * feat(cli): add a no-ranges flag to the parse command
  * fix(lib): correct descendant-for-range behavior with zero-width tokens
  * fix(lib): silence warnings with -Wpedantic
  * style(lib): add parameter names in declarations that are missing them
  * feat!: move generation of grammar files to an init command
  * chore: clippy fixes
  * feat: move generate logic to its own crate
  * feat(generate): add a no-op --no-bindings flag
  * Update cli/src/main.rs
  * refactor: improve the grammar schema
  * chore: update generate crate paths
  * build: bump deps
  * feat(init): add an update flag
  * feat!: implement StreamingIterator instead of Iterator for `Query…`
  * fix(lib)!: child_containing_descendant now returns direct children
  * feat: add --overview-only to test subcommand
  * fix: correct test name parsing when the prior test has equal signs
  * fix: handle more cases of editing subtrees that depend on column values
  * fix: exclude APIs that dup given file descriptors from WASI builds
  * feat: move tree-sitter configuration to dedicated file
  * fix(cli): generate the parser version from the config as well
  * fix: deprecate child_containing_descendant
  * fix(bindings): use RUST_BINDING_VERSION in Cargo.toml template
  * fix(bindings): lower go version to 1.22
  * build(bindings): add CMakeLists.txt file
  * feat(api): expose function to check if symbol represents a supertype
  * fix(init): fix some schema issues
  * fix(init): don't prompt to reconfigure
  * fix(init): do not migrate package.json on error
  * fix(build): correct wasm root path lookup
  * fix(generate): remove unused rules
  * fix(generate): add *.scm section to .editorconfig template
  * fix(generate): filter out unused rules in other spots
  * build(cmake): link wasmtime dependencies
  * fix(lib): ensure an unfinished state was found before removing it
  * fix(build): force rebuild parsers when build is invoked
  * build(xtask): bump cmake version in bump-version
  * build(xtask): only consider major and minor versions when validating
  * build(xtask): ignore the language crate
  * build: bump language to 0.1.1
* Tue Oct  1 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.23.1:
  * fix(generate): remove necessary files from gitignore template
  * fix(cli): remove conflicting short flags in the fuzz subcommand
  * feat(generate): bump tree-sitter dev dependency to 0.23
  * feat(bindings): bump go-tree-sitter version
  * fix(lib): correct extra node creation from non-zero root-alias cursors
  * fix(rust): add missing TSNode functions
  * fix(test): exit with an error if a test marked with :error has no error
  * fix(test): retain attributes when running test -u
  * fix(generate): disallow inline variables referencing themselves
  * feat(language): derive Clone and Copy on LanguageFn
  * fix(lib): backtrack to the last relevant iterator if no child was found
  * fix(generate): add tree-sitter to the dev-dependencies of the Cargo.toml
  * fix(binding_web): correct edit signature
  * fix(cli): keep skipped tests unchanged in the test/corpus
  * fix(generate): do not generate large character sets for unused variables
  * fix(binding_web): remove nonexistent function definition
  * fix(cli): remove duplicate short options from fuzz command
  * fix(generate): remove excludes in Package.swift
  * chore(bindings): update rust lib docs
  * fix: correct comment quote
  * build(make): support darwin cross-compile
  * fix(lib): peek at the next sibling when iterating to find the child
  * fix(docs): fix highlight readme example using compatible versions
  * build(deps): bump the cargo group across 1 directory with 11 updates
  * fix(wasm): use / paths for workdir
  * fix: properly handle utf8 code points for highlight and tag assertions
  * fix(fuzz): skip tests marked with :skip & don't report errors on them
  * fix: do not generate spurious files if the grammar path is not the default path
  * fix: disallow empty string literals in rules
  * fix(lib): correct descendant-for-range behavior with zero-width tokens
  * fix: correct test name parsing when the prior test has equal signs
  * fix: handle more cases of editing subtrees that depend on column values
  * fix: exclude APIs that dup given file descriptors from WASI builds
* Mon Aug 26 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.23.0:
  * test: modernize scanner files
  * fix: always reset to the first language when iterating over language
  * feat(zig): update outdated path syntax
  * feat(bindings): add query constants to python
  * style(bindings): fix indent & line endings
  * feat(dsl)!: support other JS runtimes
  * feat(bindings): add node, python, swift tests
  * introduce tree-sitter-language crate for grammar crates to depend on
  * refactor: remove ansi_term dependency
  * refactor: remove difference dependency
  * feat: add fuzz subcommand
  * fix(wasm): update test
  * feat(lib): add ts_query_end_byte_for_pattern
  * fix(rust): fix new clippy warnings
  * feat(lib): support no_std
  * Reset language when resetting wasm store
  * docs: clean up binding & parser lists
  * clone wasm store engine
  * fix(cli): dedup preceding_auxiliary_symbols
- use of ldconfig_scriptlets, and removal of the duplicate setting of buildflags
* Fri Jun 21 2024 Richard Rahl <rrahl0@disroot.org>
- update to version 0.22.6:
  * Improve handling of serialization buffer overflows
  * Reverse iteration through node parents
  * cli: Support NO_COLOR
  * cli: Add test listing and allow users to parse a specific test number
  * grammar: Add "inherits" field if available
  * Correctly load field data from wasm languages
  * Improve error message when the tree-sitter field is malformed
  * Don't error out on package.json lookup errors if --no-bindings is passed
  * cli: Keep default cc flags in build
  * cli: Properly account for multi-grammar repos when using docker to build a wasm parser
  * generate: Don't check arbitrarily named dirs
  * generate: Take AsRef<Path> for the path parameter to avoid clones
  * highlight: Correct signature of ts_highlighter_add_language
  * lib: Do not return field names for extras
  * lib: Advance the lookahead end byte by 4 when there's an invalid code point
  * rust: Update README example
  * rust: Use unix + wasi cfg instead of not windows for fd
  * wasm: Correct childrenFromFieldXXX method signatures
  * xtask: Always bump every crate in tandem
  * zig: Make usable as a zig dependency
  * Documentation: Mention build command variables
- update to version 0.22.5:
  * Avoid generating unused character set constants
  * rust: Compilation on wasm32-wasi
- update to version 0.22.4:
  * Fix sorting of transitions within a lex state
  * Include 2-character ranges in array-based state transitions
- update to version 0.22.3:
  * Add strncat to wasm stdlib
  * Generate simpler code for matching large character sets
  * When loading languages via WASM, gracefully handle memory errors and leaks in external scanners
  * bindings: Add utf-8 flag to python & node
  * bindings: Generate parser.c if missing
  * bindings: Remove required platforms for swift
  * cli: Fix mismatched parenthesis when accounting for &&
  * lib: Do not consider childless nodes for ts_node_parent
  * lib: Properly account for aliased root nodes and root nodes with
    children in ts_subtree_string
  * lib: Account for the root node of a tree cursor being an alias
  * lib: Use correct format specifier in log message
  * parser: Fix variadic macro
  * render: Proper function prototypes
  * Add a semicolon after SKIP macros
  * Add back build-wasm temporarily
  * Add lifetime to matches function
  * Default output directory for build --wasm should use current_dir
  * Fix sorting of wasm stdlib symbols
  * Insert "tree-sitter" section in current directory's package.json if it exists
  * Tie the lifetime of the cursor to the query in QueryCursor::captures()
  * Wrong flag check in build.rs
  * cli: Reduced the compile time of generated parsers by generating C code with fewer conditionals
  * parser: Make REDUCE macro non-variadic
  * js: Misc fixes & tidying
  * rust: Misc fixes & tidying
* Mon Mar 25 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Add workaround to packaging macros for RPM being to old on current Leap
- Add workaround for Python below 3.9 on Leap
* Fri Mar 22 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Add packaging macros for tree-sitter grammar
- Add missing dependency for tree-sitter generate
* Tue Mar 19 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.22.2:
  * fix(lib): allow hiding symbols
  * feat(lib): implement Display for Node
  * test: fix header writes
  * chore: turbofish styling
  * feat(cli)!: add a separate build command to compile parsers
  * ci: simplify workflows
  * docs(license): update year
  * fix(lib): avoid possible UB of calling memset on a null ptr when 0 is passed into `array_grow_by`
  * fix(lib): makefile installation
- Update _service file
  * replace obsoleted mode "disabled" with "manual"
  * use download_files instead of performing scm
* Thu Apr  6 2023 Andreas Schneider <asn@cryptomilk.org>
- Build AVX2 enabled hwcaps library for x86_64-v3
- Add baselibs.conf for proper generation of libraries.
* Wed Apr  5 2023 Matej Cepl <mcepl@suse.com>
- Update to version 0.20.8:
  - 0.20.8 - recovered
  - cicd: fix bug in release workflow
  - Bumps [webbrowser](https://github.com/amodm/webbrowser-rs)
    from 0.5.5 to 0.8.3.
  - cli: Bump tree-sitter dependency to 0.20.10
  - Update python error corpus to reflect grammar changes
  - Improve the performance of running a query in a small range
    of a large file
  - Add API for checking if a pattern in a query is non-local
  - Fix bug in maintenance of query cursor's tree depth
  - Restructure query_cursor_advance to explicitly control which
    hidden nodes it descends into
  - Extract 'internal' versions of tree cursor movement fns that
    allow visiting hidden nodes
  - Group analysis state sets into QueryAnalysis struct
  - Precompute the set of repetition symbols that can match
    rootless patterns
  - Add --row-range, --quiet, and --time flags to query
    subcommand
  - Fix CLI build on windows
  - Clear the parse stack when terminating parsing early due to
    error cost
  - This fixes a bug where the parse tree would not be rebalanced
    if this code path was taken.
  - Add --dot flag to parse subcommand, for printing tree as DOT
    graph
  - Derive Hash for Language
  - docs: apply `scheme` marker for all query syntax snippets
  - fix: possible rollover of nanoseconds in clock.h
  - cli: make error message more specific for building in
    `docker`
  - cli: Improve init-config with respect to TREE_SITTER_DIR
  - docs: merge of all binding and grammar link PRs
  - Exclude huge generated files from `git diff` output
  - loader: use portable way of path joining
  - loader: add TREE_SITTER_LIBDIR; cli: add --libdir to
    `tree-sitter generate`
  - cli: add -b, --build flags for `tree-sitter generate`
  - Remove unused no-minimize arg for the generate command
  - cli: Fix build.rs in case of the current branch ref was
    packed
  - Support SHA lookup in .git/packed-refs
  - fix: possible rollover of nanoseconds in clock.h
  - Fix permanent rebuild triggering in a git worktree due to
    wrong git branch file path
  - fix(cli): Racing on playground webserver port binding
  - Fix test output formatting for rules starting with M/U
  - Allow web-tree-sitter to work with Emscripten 3
  - Add __cxa_atexit to exports
  - Add `memset` to exports
  - Add 'stringToUTF16' and 'AsciiToString' to exported method
  - Configure compiled WASM grammars to not catch rejections
  - Add Erlang to list of Available Parsers
  - Fix test output formatting for rules starting with M/U
  - Previously the rule names could not begin with an uppercase
    M or U because the test output formatter assumed that they
    represent special tokens: MISSING or UEXPECTED.
  - Allow retrieving a tree's list of included ranges, fix some
    included range bugs
  - Add tests that randomly edit files with disjoint included
    ranges
  - Fix suppression of empty tokens during error handling at
    included range boundaries
  - Fix parse error when reusing a node at the end of an included
    range
  - fix(cli): Racing on playground webserver port binding
  - Add doc comments for tree included ranges getter
  - Fix adjustment of trees' included ranges on edits
  - Add D grammar - it is quite complete for D 2.100.
  - Add Erlang to list of Available Parsers
  - Add twig parser in documentation
  - Fix integer size of subtree's child count field
  - Explain in the docs that npm install supports limited
    platforms
- Removed upstreamed patch CVE-2022-45299-update-webbrowser.patch
* Wed Mar  1 2023 Matej Cepl <mcepl@suse.com>
- VERSION string used in generating *.pc file
  (among other things) has been hardcoded to 0.6.3
  (gh#tree-sitter/tree-sitter#1608), we should at least fix it
  using sed.
* Wed Jan 18 2023 Matej Cepl <mcepl@suse.com>
- Add CVE-2022-45299-update-webbrowser.patch (copied from
  gh#tree-sitter/tree-sitter#2042) to use more recent version
  of webbrowser-rs, which has been fixed against CVE-2022-45299
  (bsc#1207196).
* Sat Sep 24 2022 socvirnyl.estela@gmail.com
- Update to version 0.20.7:
  * 0.20.7
  * Bump library versions
  * Build core wasm library with C++ exceptions disabled
  * Generate parsers with ABI version 14 by default
  * Tolerate tree edits whose old range extends beyond the end of the tree
  * Added documentation on web-tree-sitter edge cases
  * Add ts_tree_root_node_with_offset API
  * Fix typos
  * Update section-2-using-parsers.md
  * Add link to Racket language parser
* Sun Jun 19 2022 socvirnyl.estela@gmail.com
- Update to version 0.20.6:
  * 0.20.6
  * libs: 0.20.6
  * Properly incorporate lookahead bytes when recovering via missing token
  * Improve randomized testing setup
  * Run cargo test directly on CI
  * Set CLI as default workspace member
  * Don't generate primary states array if it will be unused due to abi version setting
  * tags: 0.20.2
  * 0.20.5
  * libs: 0.20.5
* Tue Feb 22 2022 Matej Cepl <mcepl@suse.com>
- Update to 0.20.4:
  - Always generate parser.h, regardless of chosen ABI version
  - add test for removals in eager query matches
  - remove non-local query matches for locals
  - remove unfinished queries from 'ts_query_cursor_remove_match'
  - prevent future matches for '#is-not? local' patterns
  - Represent quantifiers using bytes instead of ints
  - Prefix globally visible TSquantifier values
  - Rewrite quantifier oeprations
  - Add pointer indirection to AnalysisStateSet
  - Fixed rust build, updated docs
  - get_column now counts codepoints
  - Add realloc to wasm exports
  - Add link to Protocol Buffers grammar
  - Convert more fixture grammars from JSON to JS
  - Simplify allocation-recording in test suite using new
    ts_set_allocator API
  - Address feedback
  - Make SubtreeInlineData work on Big-Endian
  - Replace allocator struct with function pointers
  - cli: Fix parsing of test files with newlines in test names
  - Avoid allocator from being switched more than once
  - Remove ts_allocator from api.h
  - Add TSAllocator and ts_set_allocator in api.h
  - Fix declaration of ts_toggle_allocation_recording
  - Allow to change the allocator dynamically
  - Support @module as a highlight key.
  - add link to in-development Elixir parser
  - Added bindings for Java and Kotlin to `index.md`
  - Remove unnecessary types from binding.rs
  - Always include playground.html in the CLI binary
  - playground: Make query error underlines render in safari
  - web: Fix script directory that's passed to locateFile
  - Use serde's derive feature everywhere
  - Improve query execution logging
  - Rename Query::step_is_definite ->
    is_pattern_guaranteed_at_step
  - Add link to Lua bindings
  - Convert more test grammars from JSON to JS
  - Add link to swift bindings package
  - Convert some of the fixture grammars from JSON to JS
  - Use serde's derive feature
  - Simplified corpus test output comparisons
  - Add link to elisp parser
  - Add tree-sitter-cuda, tree-sitter-glsl,
    tree-sitter-commonlisp
  - Avoid dynamic regex construction when parsing test files
  - chore(cli): Rename all internal web_ui stuff to playground
  - cli(query): Improve and unify query subcommand output
  - binding(rust): Mark set_cancellation_flag self as mutable
  - fix(wasm): Fix predicates in alternations, resolves #1392
  - fix(cli): Panic on queries containing alternation with
    predicates
  - Add WGSL WebGPU Shading Language
  - Add HCL (Terraform) and Hack to the list of supported
    languages
  - Add link to OCaml bindings to list and sort list
    alphabetically.
  - Add Objective-C language parser
  - feat(rust): Add an id() method for QueryMatch
  - Assign ids to query matches only when the matches are
    returned
  - feat(cli): add a flag to compile a parser in debug mode with
  - O0 C/C++ compiler flag
  - Put emscripten-version file in cli directory
  - Fix 'include!' error when building the CLI outside of the
    repo
  - fix(lib): fix segfault on ts_query_new with incompatible
    grammar version, close #1318
  - Add Graphviz DOT parser
  - chore(web): Add the LICENSE file to the web-tree-sitter npm
    package
  - chore(cli): Add the LICENSE file to the tree-sitter-cli npm
    package
  - Support for suffixes in test file separators Some languages
    use the non-suffixed separators in their syntax Fixes #982
  - Handle aliases in unicode property escapes in regexes
  - Update `smallbitvec` dependency
  - `Generator::add_parse_table`: Store entries in hash map
  - Use `IndexMap` and `FxHash` for some hot hash maps
  - fix(cli): Remove tree-sitter grammar ./... call limitation
  - Always print where the playground is running
  - Correct quiet description for playground
  - fix(cli): allow dead code in Logger
  - docs(Using parsers): Fix spelling, remove unusual keyword
  - Fix highlighting typo on "creating parsers" site
  - feat(cli): Make "test" output more readable
  - fix(cli): Improve error messages on config.json loading,
    closes #1227
  - fix(parser): count rows in the debug log from 0
  - Docs: document `_` wildcard node
  - Add SQL parser
  - feat(cli): Add a lot of help messages for CLI options
  - fix(cli): fix theme key loading from config.json, closes
    [#1232]
  - fix(cli): Avoid ENOENT if config.json is not in
    TREE_SITTER_DIR
  - feat(cli/loader): Add TREE_SITTER_INTERNAL_BUILD C/C++
    compiler definition
  - feat(cli): Set TREE_SITTER_DEBUG env var on 'tree-sitter
    parse -d'
  - allow `~` or `$HOME` in `parser-directories`
  - update set_included_ranges to modify extent if the current
    position is at the very beginning of the included range
* Fri Nov  5 2021 William Brown <william.brown@suse.com>
- Add cargo audit service to detect potential security issues
* Fri Jul  2 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.20.0.
* Tue Apr 27 2021 Duncan Mac-Vicar <duncan@mac-vicar.eu>
- Update to 0.19.4.
* Thu Mar 18 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.19.3.
* Wed Feb 24 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.18.2:
  There isn’t good changelog, so the best I have is
  https://github.com/tree-sitter/tree-sitter/compare/0.17.3...v0.18.2
* Sun Nov 15 2020 Matej Cepl <mcepl@suse.com>
- Add fix_build_aarch64.patch (gh#tree-sitter/tree-sitter#804) to fix
  build on aarch64.
* Sat Nov  7 2020 Matej Cepl <mcepl@suse.com>
- The initial packaging of tree-sitter 0.17.3.
